==> sumus-7.0.3-sources.jar: io/intino/sumus/box/displays/notifiers/SumusTimeSeriesChartNotifier.java <==
package io.intino.sumus.box.displays.notifiers;

import io.intino.konos.alexandria.exceptions.*;
import io.intino.sumus.box.*;
import io.intino.sumus.box.schemas.*;

public class SumusTimeSeriesChartNotifier extends io.intino.konos.alexandria.activity.displays.AlexandriaDisplayNotifier {

    public SumusTimeSeriesChartNotifier(io.intino.konos.alexandria.activity.displays.AlexandriaDisplay display, io.intino.konos.alexandria.activity.displays.MessageCarrier carrier) {
        super(display, carrier);
    }

	public void olapRange(Range value) {
		putToDisplay("olapRange", "value", value);
	}

	public void timeRange(Range value) {
		putToDisplay("timeRange", "value", value);
	}

	public void formats(java.util.List<Formatter> value) {
		putToDisplay("formats", "value", value);
	}

	public void updateScale(Scale value) {
		putToDisplay("updateScale", "value", value);
	}

	public void clear() {
		putToDisplay("clear");
	}

	public void refreshTicketCount(Integer value) {
		putToDisplay("refreshTicketCount", "value", value);
	}

	public void refreshEventListCount(Double value) {
		putToDisplay("refreshEventListCount", "value", value);
	}

	public void refreshEventList(java.util.List<Event> value) {
		putToDisplay("refreshEventList", "value", value);
	}

	public void addSeries(java.util.List<Serie> value) {
		putToDisplay("addSeries", "value", value);
	}

	public void removeSeries(java.util.List<String> value) {
		putToDisplay("removeSeries", "value", value);
	}

	public void addPoints(Points value) {
		putToDisplay("addPoints", "value", value);
	}

	public void refreshCatalogList(java.util.List<Reference> value) {
		putToDisplay("refreshCatalogList", "value", value);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/box/displays/notifiers/SumusTimeSeriesChartNotifier.java <==
package io.intino.sumus.box.displays.notifiers;

import io.intino.konos.alexandria.exceptions.*;
import io.intino.sumus.box.*;
import io.intino.sumus.box.schemas.*;

public class SumusTimeSeriesChartNotifier extends io.intino.konos.alexandria.ui.displays.AlexandriaDisplayNotifier {

    public SumusTimeSeriesChartNotifier(io.intino.konos.alexandria.ui.displays.AlexandriaDisplay display, io.intino.konos.alexandria.rest.pushservice.MessageCarrier carrier) {
        super(display, carrier);
    }

	public void olapRange(Range value) {
		putToDisplay("olapRange", "value", value);
	}

	public void timeRange(Range value) {
		putToDisplay("timeRange", "value", value);
	}

	public void formats(java.util.List<Formatter> value) {
		putToDisplay("formats", "value", value);
	}

	public void updateScale(Scale value) {
		putToDisplay("updateScale", "value", value);
	}

	public void clear() {
		putToDisplay("clear");
	}

	public void refreshTicketCount(Integer value) {
		putToDisplay("refreshTicketCount", "value", value);
	}

	public void refreshEventListCount(Double value) {
		putToDisplay("refreshEventListCount", "value", value);
	}

	public void refreshEventList(java.util.List<Event> value) {
		putToDisplay("refreshEventList", "value", value);
	}

	public void addSeries(java.util.List<Serie> value) {
		putToDisplay("addSeries", "value", value);
	}

	public void removeSeries(java.util.List<String> value) {
		putToDisplay("removeSeries", "value", value);
	}

	public void addPoints(Points value) {
		putToDisplay("addPoints", "value", value);
	}

	public void refreshCatalogList(java.util.List<Reference> value) {
		putToDisplay("refreshCatalogList", "value", value);
	}
}
